=================================
 Tempest Plugin for Neutron L2GW
=================================

This project defines a tempest plugin containing tests used to verify the
functionality of the Neutron L2GW service plugin. The plugin will automatically
load these tests into tempest.
